DATA_DIR = "/usr/local/share"
LIB_DIR = "/usr/local/libexec"
VERSION = "2.29.90"
PACKAGE = "deskbar-applet"
